UI — QuadratiK 1.0.0 documentation

Skip to main content
`Ctrl`+`K`

# UI

class QuadratiK.ui.UI

  The UI class is a user interface class that runs a Streamlit dashboard using asyncio.

  ## Examples

      >>> from QuadratiK.ui import UI
      >>> UI().run()

Methods

`UI.main`() | The main function runs a Streamlit dashboard by executing a command-line command.
`UI.run`() | The function runs the main function asynchronously using the asyncio library in Python.

async UI.main()

  The main function runs a Streamlit dashboard by executing a command-line command.

UI.run()

  The function runs the main function asynchronously using the asyncio library in Python.